enforce_parent_unlocked

Function enforce_parent_unlocked 

pub async fn enforce_parent_unlocked(
    lock_system: &dyn DavLockSystem,
    path: &DavPath,
    prefix: &str,
    if_header: Option<&IfHeader>,
    request_scheme: &str,
    request_host: &str,
) -> Result<DavMutationCredentials, DavLockEnforcementError>
Enforces lock submission for the canonical parent and returns a compact typed failure.

Errors

Returns DavLockEnforcementError when the parent is locked or lock lookup fails.