enforce_unlocked

Function enforce_unlocked 

pub async fn enforce_unlocked(
    lock_system: &dyn DavLockSystem,
    path: &DavPath,
    deep: bool,
    prefix: &str,
    if_header: Option<&IfHeader>,
    request_scheme: &str,
    request_host: &str,
) -> Result<DavMutationCredentials, DavLockEnforcementError>
Enforces resource lock submission and returns a compact typed failure.

Errors

Returns DavLockEnforcementError when a conflicting lock exists or lock lookup fails.