pub async fn ensure_empty_body(
payload: &mut Payload,
) -> Result<(), DavBodyError>Expand description
Rejects the first non-empty request body chunk without buffering the remaining payload.
pub async fn ensure_empty_body(
payload: &mut Payload,
) -> Result<(), DavBodyError>Rejects the first non-empty request body chunk without buffering the remaining payload.