pub fn method_gate_error_response(
snapshot: &DavCapabilitySnapshot,
) -> HttpResponseExpand description
Maps a rejected method gate to the canonical 405 Actix response.
pub fn method_gate_error_response(
snapshot: &DavCapabilitySnapshot,
) -> HttpResponseMaps a rejected method gate to the canonical 405 Actix response.