pub fn parent_collection_error_response(
error: DavParentCollectionError,
) -> HttpResponseExpand description
Maps parent-collection enforcement failures to Actix at the handler boundary.
pub fn parent_collection_error_response(
error: DavParentCollectionError,
) -> HttpResponseMaps parent-collection enforcement failures to Actix at the handler boundary.