pub struct DavIfResourceState {
pub etag: Option<String>,
pub lock_tokens: Vec<String>,
}Expand description
Protocol-visible state used to evaluate one resource referenced by an If header.
Fields
etag: Option<String>lock_tokens: Vec<String>Trait Implementations
Sourceimpl Clone for DavIfResourceState
impl Clone for DavIfResourceState
Sourcefn clone(&self) -> DavIfResourceState
fn clone(&self) -> DavIfResourceState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DavIfResourceState
impl Debug for DavIfResourceState
Sourceimpl Default for DavIfResourceState
impl Default for DavIfResourceState
Sourcefn default() -> DavIfResourceState
fn default() -> DavIfResourceState
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for DavIfResourceState
impl PartialEq for DavIfResourceState
Sourcefn eq(&self, other: &DavIfResourceState) -> bool
fn eq(&self, other: &DavIfResourceState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DavIfResourceState
impl StructuralPartialEq for DavIfResourceState