DavDirectoryEntry

Trait DavDirectoryEntry 

pub trait DavDirectoryEntry: Send {
    type Metadata: DavMetaData;

    // Required methods
    fn name(&self) -> &[u8] ;
    fn metadata(&self) -> &Self::Metadata;

    // Provided method
    fn stable_key(&self) -> &[u8]  { ... }
}
One entry returned by a bounded directory page.

Metadata is part of the page so product adapters can batch it with enumeration instead of creating an N+1 lookup contract. stable_key must be strictly ordered within and across pages.

Required Associated Types

Required Methods

fn name(&self) -> &[u8]

fn metadata(&self) -> &Self::Metadata

Provided Methods

fn stable_key(&self) -> &[u8]

Implementors