pub enum DavAutoVersion {
None,
CheckoutCheckin,
CheckoutUnlockedCheckin,
Checkout,
LockedCheckout,
}Expand description
Automatic side effects selected by a product for checked-in resources.
Variants
None
Mutation requires an explicitly checked-out resource.
CheckoutCheckin
Automatically check out before mutation and check in after it succeeds.
CheckoutUnlockedCheckin
Check out before mutation, then check in unless the resource is write-locked.
Checkout
Automatically check out before mutation and leave the resource checked out.
LockedCheckout
Automatically check out only when the checked-in resource is write-locked.