plan_conditionals_with_backends

Function plan_conditionals_with_backends 

pub async fn plan_conditionals_with_backends(
    if_header: Option<&IfHeader>,
    filesystem: &dyn DavFileSystem,
    lock_system: &dyn DavLockSystem,
    request_path: &DavPath,
    prefix: &str,
    request_scheme: &str,
    request_host: &str,
    method: DavMethod,
    headers: &HeaderMap,
    resource: DavConditionalResource<'_>,
) -> Result<DavConditionalPlan, DavConditionalEvaluationError>
Enforces WebDAV If through the canonical backend ports, then applies HTTP conditions.

This has the same WebDAV-first ordering as plan_conditionals.

Errors

Returns an error when backend state lookup or conditional evaluation fails.