DavReportLimits

Struct DavReportLimits 

pub struct DavReportLimits {
    pub maximum_input_bytes: usize,
    pub maximum_xml_depth: usize,
    pub maximum_selection_depth: usize,
    pub maximum_selection_properties: usize,
    pub maximum_expansion_depth: usize,
    pub maximum_expanded_resources: usize,
    pub maximum_expanded_properties: usize,
    pub multistatus: DavMultiStatusLimits,
}
Independent hard limits for REPORT grammar, traversal, and response composition.

Fields

maximum_input_bytes: usizemaximum_xml_depth: usizemaximum_selection_depth: usize

Maximum nested DAV:property levels in the request selection AST, counted from one.

maximum_selection_properties: usize

Maximum DAV:property nodes in the request selection AST.

maximum_expansion_depth: usize

Maximum resource expansion hops, counted from zero at the root resource.

maximum_expanded_resources: usize

Maximum resources visited during expansion, including the root resource.

maximum_expanded_properties: usize

Maximum backend property lookups performed during expansion.

multistatus: DavMultiStatusLimits