pub enum DavEventOutcome {
Succeeded {
status: u16,
},
Failed {
status: u16,
backend_error: Option<DavBackendErrorKind>,
},
}Expand description
Protocol result exposed to observers without credentials, bodies, or lock tokens.
Variants
Implementations
Sourceimpl DavEventOutcome
impl DavEventOutcome
Sourcepub const fn from_status(
status: u16,
backend_error: Option<DavBackendErrorKind>,
) -> Self
pub const fn from_status( status: u16, backend_error: Option<DavBackendErrorKind>, ) -> Self
Classifies a completed response. Informational, success, and redirection statuses are successful protocol outcomes; client and server errors are failures.