pub fn publish_non_authoritative(
sink: Option<&dyn DavEventSink>,
event: &DavEvent,
)Expand description
Publishes a non-authoritative event without allowing observer failure to affect the operation.
pub fn publish_non_authoritative(
sink: Option<&dyn DavEventSink>,
event: &DavEvent,
)Publishes a non-authoritative event without allowing observer failure to affect the operation.