DavEvent

Struct DavEvent 

pub struct DavEvent {
    pub request_id: Option<String>,
    pub operation: DavOperation,
    pub source: DavPath,
    pub destination: Option<DavPath>,
    pub outcome: DavEventOutcome,
    pub elapsed: Duration,
}
One completed WebDAV operation.

Fields

request_id: Option<String>operation: DavOperationsource: DavPathdestination: Option<DavPath>outcome: DavEventOutcomeelapsed: Duration

Implementations

Source

impl DavEvent

pub fn completed( request_head: &DavRequestHead, status: u16, elapsed: Duration, backend_error: Option<DavBackendErrorKind>, ) -> Self

Builds the transport-neutral event for one completed request.

Only protocol routing data is copied from the request head. Conditional headers, credentials, request bodies, and lock tokens are deliberately excluded.