pub fn extension_body_kind(
packages: DavExtensionSet,
resource: DavResourceState,
method: DavMethod,
) -> Option<DavExtensionBodyKind>Expand description
Returns the extension body contract for a method on the selected resource.
pub fn extension_body_kind(
packages: DavExtensionSet,
resource: DavResourceState,
method: DavMethod,
) -> Option<DavExtensionBodyKind>Returns the extension body contract for a method on the selected resource.