pub fn lock_conflict_response(
prefix: &str,
path: &DavPath,
) -> Result<DavResponse, DavXmlError>Expand description
Builds a 423 response identifying the lock whose token must be submitted.
pub fn lock_conflict_response(
prefix: &str,
path: &DavPath,
) -> Result<DavResponse, DavXmlError>Builds a 423 response identifying the lock whose token must be submitted.