pub fn unlock_token_mismatch_response() -> Result<DavResponse, DavXmlError>Expand description
Builds the 409 response for an UNLOCK token that does not match the request URI.
pub fn unlock_token_mismatch_response() -> Result<DavResponse, DavXmlError>Builds the 409 response for an UNLOCK token that does not match the request URI.