DavMutationStepError

Enum DavMutationStepError 

pub enum DavMutationStepError {
    Locked {
        affected_path: DavPath,
        lock_root: DavPath,
    },
    Status {
        affected_path: DavPath,
        status: u16,
    },
}
Typed failure returned by the authoritative product mutation port.

Variants



Locked

Fields

affected_path: DavPath
lock_root: DavPath


Status

Fields

affected_path: DavPath
status: u16

Implementations

Source

impl DavMutationStepError

pub fn locked(affected_path: DavPath, lock_root: DavPath) -> Self

pub fn status(affected_path: DavPath, status: u16) -> Self

pub fn backend(affected_path: DavPath) -> Self

pub fn from_backend(affected_path: DavPath, error: &DavBackendError) -> Self

Maps one typed backend failure to the canonical resource status.