pub fn decode_relative_path(relative: &str) -> Result<DavPath, DavPathError>Expand description
Parses a mount-relative request path and returns its canonical decoded representation.
pub fn decode_relative_path(relative: &str) -> Result<DavPath, DavPathError>Parses a mount-relative request path and returns its canonical decoded representation.