pub enum DavPutWritePlan {
Replace,
Partial(DavPartialPutPlan),
PrivateUpdateRange {
value: HeaderValue,
},
}Expand description
Product write operation selected from the declared PUT compatibility capabilities.
Variants
Replace
Replace the complete representation using ordinary PUT semantics.
Partial(DavPartialPutPlan)
Replace one byte range relative to the current selected representation.
PrivateUpdateRange
Execute the explicitly enabled private header contract in the product adapter.
Fields

value: HeaderValueTrait Implementations
Sourceimpl Clone for DavPutWritePlan
impl Clone for DavPutWritePlan
Sourcefn clone(&self) -> DavPutWritePlan
fn clone(&self) -> DavPutWritePlan
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DavPutWritePlan
impl Debug for DavPutWritePlan
Sourceimpl PartialEq for DavPutWritePlan
impl PartialEq for DavPutWritePlan
impl Eq for DavPutWritePlan
impl StructuralPartialEq for DavPutWritePlan