pub fn put_plan_error_response(
snapshot: &DavCapabilitySnapshot,
error: &DavPutPlanError,
) -> DavResponseExpand description
Maps a PUT planning failure through the same snapshot used for method planning.
pub fn put_plan_error_response(
snapshot: &DavCapabilitySnapshot,
error: &DavPutPlanError,
) -> DavResponseMaps a PUT planning failure through the same snapshot used for method planning.