pub fn backend_error_response(error: &DavBackendError) -> DavResponseExpand description
Maps a classified product backend failure to the WebDAV status contract.
pub fn backend_error_response(error: &DavBackendError) -> DavResponseMaps a classified product backend failure to the WebDAV status contract.