pub fn range_not_satisfiable_response(content_length: u64) -> DavResponseExpand description
Builds the response required when a byte range cannot be served.
pub fn range_not_satisfiable_response(content_length: u64) -> DavResponseBuilds the response required when a byte range cannot be served.