pub trait DavCancellation: Send + Sync {
// Required method
fn is_cancelled(&self) -> bool;
}Expand description
Cancellation checkpoint controlled by the product or transport adapter.
pub trait DavCancellation: Send + Sync {
// Required method
fn is_cancelled(&self) -> bool;
}Cancellation checkpoint controlled by the product or transport adapter.