pub fn parse_lock_request(
body: &[u8],
) -> Result<DavLockRequestBody, DavXmlError>Expand description
Parses a LOCK creation body.
Errors
Returns DavXmlError when the body is unsafe or violates LOCK creation grammar.
pub fn parse_lock_request(
body: &[u8],
) -> Result<DavLockRequestBody, DavXmlError>Parses a LOCK creation body.
Returns DavXmlError when the body is unsafe or violates LOCK creation grammar.