pub async fn unsubmitted_lock_conflicts(
lock_system: &dyn DavLockSystem,
path: &DavPath,
deep: bool,
prefix: &str,
if_header: Option<&IfHeader>,
request_scheme: &str,
request_host: &str,
) -> Result<Vec<DavLock>, DavBackendError>Expand description
Returns conflicting locks whose tokens were not submitted for their corresponding lock root.
Errors
Returns DavBackendError when the product lock backend cannot query conflicting locks.