pub async fn enforce_parent_collection(
filesystem: &dyn DavFileSystem,
target: &DavPath,
) -> Result<(), DavResponse>Expand description
Requires the canonical parent of a mutation target to exist as a collection.
The DAV mount root is an implicit collection and does not require a backend lookup. A target without a parent identifies the mount root itself and is rejected for mutation.