DavMutationFailure

Struct DavMutationFailure 

pub struct DavMutationFailure { /* private fields */ }
One resource-level failure from a recursive COPY, MOVE, or DELETE operation.

Implementations

Source

impl DavMutationFailure

pub fn locked(path: DavPath, lock_path: DavPath) -> Self

Creates a recursive mutation failure caused by an unsubmitted lock token.

pub fn status(path: DavPath, status: u16) -> Self

Creates a recursive mutation failure with an explicit protocol status.