pub fn validate_directory_page<E, C, S>(
current_cursor: Option<&C>,
seen_cursors: &HashSet<C, S>,
previous_stable_key: Option<&[u8]>,
maximum_entries: usize,
page: &DavDirectoryPage<E, C>,
) -> Result<(), DavDirectoryPageValidationError>Expand description
Validates product page bounds, ordering and cursor progress before protocol consumption.
Errors
Returns an error when limits, ordering, entries, or cursor progress are invalid.